// Web.h
/*
Copyright (C) 2003  Anders Hedstrom

This program is free software; you can redistribute it and/or
modify it under the terms of the GNU General Public License
as published by the Free Software Foundation; either version 2
of the License, or (at your option) any later version.

This program is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU General Public License for more details.

You should have received a copy of the GNU General Public License
along with this program; if not, write to the Free Software
Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
*/

#ifndef _WEB_H
#define _WEB_H

#include <string>
#include <vector>

class Form;
class Cookies;

//! The CGI main class

class Web 
{
public:
	Web();
	Web(const std::string &,const std::string &);
	Web(int argc,char *argv[],const std::string &,const std::string &);
	virtual ~Web();

	void Init();

	void SetCookieDomain(const std::string &);
	void SetCookiePath(const std::string &);
	void SetCookie(const std::string &name,const std::string &value);
	void SetCookie(const std::string &name,long value);
	void SetCookie(const std::string &name,int value);
	void Execute();
	void SetCgiName(const std::string &);
	std::string GetCgiName();
	Form *GetForm();
	Cookies *GetCookies();

	void RegWebForm(WebForm *);

	virtual void ReadCookies();
	virtual void FormInput();
	virtual void CreateHeader();
	virtual void GenerateDocument();

	std::string GetDate();
	std::string GetRequestMethod();
	void UpdateModified(const std::string& );
	std::string datetime2httpdate(const std::string& dt);
	const std::string& GetLastModified() { return m_lastmodified; }

protected:
	Form *m_pclForm;
	Cookies *m_pclCookies;

private:
	std::string m_strCookieDomain;
	std::string m_strCookiePath;
	std::string m_strCgiName;
	std::vector<WebForm *> m_forms;
	std::string m_date;
	std::string m_method; // request_method
	std::string m_lastmodified;
};


#endif // _WEB_H
